@@ -1,5 +1,5 @@
-# platform = Red Hat Enterprise Linux 7,Red Hat Enterprise Linux 8,Red Hat Virtualization 4,multi_platform_fedora,multi_platform_ol,multi_platform_wrlinux
-. /usr/share/scap-security-guide/remediation_functions
+# platform = multi_platform_all
+
 {{{ bash_instantiate_variables("var_password_pam_retry") }}}
 
 if grep -q "retry=" /etc/pam.d/system-auth ; then
