@@ -12,6 +12,7 @@ from .constants import (product_directories,
                         DEFAULT_GRUB2_UEFI_BOOT_PATH,
                         DEFAULT_DCONF_GDM_DIR,
                         DEFAULT_AIDE_CONF_PATH,
+                        DEFAULT_AIDE_BIN_PATH,
                         PKG_MANAGER_TO_SYSTEM,
                         PKG_MANAGER_TO_CONFIG_FILE,
                         XCCDF_PLATFORM_TO_PACKAGE)
@@ -59,6 +60,9 @@ def _get_implied_properties(existing_properties):
     if "aide_conf_path" not in existing_properties:
         result["aide_conf_path"] = DEFAULT_AIDE_CONF_PATH
 
+    if "aide_bin_path" not in existing_properties:
+        result["aide_bin_path"] = DEFAULT_AIDE_BIN_PATH
+
     return result
 
 
@@ -117,11 +121,18 @@ def get_all(ssg_root):
     return products(linux_products, other_products)
 
 
+def get_profiles_directory(env_yaml):
+    profiles_root = None
+    if env_yaml:
+        profiles_root = required_key(env_yaml, "profiles_root")
+    return profiles_root
+
+
 def get_profile_files_from_root(env_yaml, product_yaml):
     profile_files = []
     if env_yaml:
+        profiles_root = get_profiles_directory(env_yaml)
         base_dir = os.path.dirname(product_yaml)
-        profiles_root = required_key(env_yaml, "profiles_root")
         profile_files = sorted(glob("{base_dir}/{profiles_root}/*.profile"
                                .format(profiles_root=profiles_root, base_dir=base_dir)))
     return profile_files
